scxpand.util.model\_type
========================

.. automodule:: scxpand.util.model_type

   
   .. rubric:: Functions

   .. autosummary::
   
      get_available_model_types
      infer_model_type_from_parameters
      load_model_type
      save_model_type
   